@@ -1,11 +1,12 @@
 ## File Name: ma_exists.R
-## File Version: 0.01
+## File Version: 0.03
 
 ma_exists <- function( x, pos, n_index=1:8)
 {
     n_index <- n_index + 1
     is_there <- exists(x, where=pos)
     obj <- NULL
+    nn <- 0
     if (is_there){
         obj <- get(x, pos)
     }
@@ -16,10 +17,10 @@ ma_exists <- function( x, pos, n_index=1:8)
             if (is_there){
                 obj <- get(x, pos)
                 break
-            }        
+            }
         }
     }
     #--- output
-    res <- list( is_there=is_there, obj=obj, pos=pos)
+    res <- list( is_there=is_there, obj=obj, pos=pos, n=nn)
     return(res)
 }
