@@ -1,15 +1,14 @@
 ## File Name: mice.impute.pmm3.R
-## File Version: 4.53
+## File Version: 4.56
 
 
 mice.impute.pmm3 <- function (y, ry, x, donors=3, noise=10^5, ridge=10^(-5), ...)
 {
     x <- cbind(1, as.matrix(x))
-    Nmis <- sum(!ry)
-    parm <- .norm.draw3(y, ry, x, ridge=ridge,  ...)
-    yhatobs <- x[ry, ] %*% parm$coef
-    yhatmis <- x[!ry, ] %*% parm$beta
-    yobs <- y[ ry ]
+    res <- miceadds_norm_draw(y=y, ry=ry, x=x, ridge=ridge, ...)
+    yhatobs <- res$yhatobs
+    yhatmis <- res$yhatmis
+    yobs <- res$yobs
     # define distance matrix
     M1 <- matrix( yhatobs[,1], nrow=sum(!ry), ncol=sum(ry), byrow=TRUE )
     M2 <- matrix( yhatmis[,1], nrow=sum(!ry), ncol=sum(ry) )
